<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
															xmlns:xlink="http://www.w3.org/1999/xlink"
															xmlns:fo="http://www.w3.org/1999/XSL/Format"
>
<!-- 	******************************************************************************************** 
			MiLCA XSLT Stylesheet 
			Fragen und Anregungen: Maik Stuehrenberg, JLU Giessen 
			maik.stuehrenberg@uni-giessen.de 
			zuletzt geaendert am: 10-04-2003, 10:35 
 			******************************************************************************************** -->
 			
<!-- 	******************************************************************************************** 
			Letzte Änderung:
			- Inhaltsverzeichnis: Nummerierung rausgenommen
														Bibliography, Glossar und Test tauchen im TOC nicht auf
			- Fließtext: vor Bibliography Page-break eingefügt
									 Links werden mit Fußnote gesetzt
			********************************************************************************************-->

	<xsl:output indent="yes"/>
	
	<xsl:variable name="bib">
		<xsl:value-of select="generate-id()"/>
	</xsl:variable>

	<xsl:variable name="gloss">
		<xsl:value-of select="generate-id()"/>
	</xsl:variable>

<!-- LearningObject -->
	<xsl:template match="LearningObject">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="title"
															 page-height="297mm"
															 page-width="210mm"
															 margin-bottom="15mm"
															 margin-left="20mm"
															 margin-right="25mm"
															 margin-top="20mm">	
					<fo:region-body margin-top="40mm"
													margin-bottom="32mm"/>
				</fo:simple-page-master>
				<fo:simple-page-master master-name="a4"
															 page-height="297mm"
															 page-width="210mm"
															 margin-bottom="7mm"
															 margin-left="25mm"
															 margin-right="25mm"
															 margin-top="15mm">
					<fo:region-before extent="15mm"/>
					<fo:region-body margin-top="15mm"
													margin-bottom="28mm"/>
					<fo:region-after extent="16mm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<xsl:choose>
				<xsl:when test="MetaData/General/@AggregationLevel>=3">
					<fo:page-sequence master-reference="title" language="de" widows="2">	
						<fo:flow flow-name="xsl-region-body">
							<fo:block font-size="24pt" 
												font-family="serif" 
												line-height="32pt" 
												font-weight="bold" 
												text-align="center">
								<xsl:value-of select="MetaData/General/Title"/>
							</fo:block>
							<fo:block font-size="12pt"
												font-family="serif"
												line-height="18pt"
												text-align="center"
												space-after="50mm">
								<xsl:for-each select="MetaData/Lifecycle/Contribute/Entity">
									<xsl:if test="../@Role='Author'">
										<xsl:choose>
											<xsl:when test="vCard">
												<xsl:value-of select="vCard/FN"/>		
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="."/>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:if test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:if>
									</xsl:if>
								</xsl:for-each>
							</fo:block>
							<fo:block font-size="14pt"
												font-weight="bold"
												font-family="serif"
												line-height="18pt"
												text-align="center">
								<xsl:text>Zusammenfassung:</xsl:text>
							</fo:block>
							<fo:block font-size="12pt"
												font-family="serif"
												line-height="18pt"
												text-align="justify"
												text-align-last="start"
												space-after="12pt">
								<xsl:value-of select="MetaData/General/Description"/>
							</fo:block>
						</fo:flow>
					</fo:page-sequence>
					<fo:page-sequence master-reference="a4" initial-page-number="1" language="de" widows="2">
						<fo:flow flow-name="xsl-region-body">
							<fo:block font-size="18pt" 
                				font-family="serif" 
                				line-height="27pt" 
                				text-align="justify">
          			<xsl:text>Inhaltsverzeichnis</xsl:text>
          		</fo:block>
          		<fo:table>
								<fo:table-column column-width="133mm"/>
								<fo:table-column column-width="8mm"/>
								<fo:table-body font-family="serif">
<!-- erster Durchlauf: TOC -->
									<xsl:for-each select="//Content/LearningObject">
										<xsl:choose>
											<xsl:when test="MetaData/General/@AggregationLevel>1">
												<fo:table-row>
													<fo:table-cell>
														<xsl:choose>
															<xsl:when test="MetaData/General/@AggregationLevel>2">
																<fo:block text-align="start" font-size="12pt" line-height="18pt" font-weight="bold">
																	<xsl:value-of select="MetaData/General/Title"/>
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block text-align="start" font-size="10pt" line-height="15pt" font-weight="bold">
																	<xsl:value-of select="MetaData/General/Title"/>
																</fo:block>
															</xsl:otherwise>
														</xsl:choose>
													</fo:table-cell>
													<fo:table-cell>
														<fo:block text-align="end" font-size="12pt" line-height="18pt" font-weight="bold">
															<fo:page-number-citation>
																<xsl:attribute name="ref-id">
																	<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
																</xsl:attribute>
															</fo:page-number-citation>
														</fo:block>
													</fo:table-cell>
												</fo:table-row>
												<fo:table-row>
													<fo:table-cell>
														<xsl:choose>
															<xsl:when test="MetaData/General/@AggregationLevel>2">
																<fo:block text-align="start" font-size="10pt" line-height="15pt" font-style="italic">
																	<xsl:value-of select="MetaData/General/Description"/>
																</fo:block>
															</xsl:when>
														</xsl:choose>
													</fo:table-cell>
												</fo:table-row>
											</xsl:when>
										</xsl:choose>
									</xsl:for-each>														
								</fo:table-body>
							</fo:table>
						</fo:flow>
					</fo:page-sequence>
<!-- zweiter Durchlauf: Inhalt -->
					<xsl:for-each select="//LearningObject">
						<xsl:choose>
							<xsl:when test="MetaData/General/@AggregationLevel=2">
								<fo:page-sequence master-reference="a4" language="de" widows="2">	
									<fo:static-content flow-name="xsl-region-before"> 
										<fo:block font-size="12pt"
															font-family="serif"
															font-style="italic"
															text-align="start">
											<xsl:value-of select="MetaData/General/Title"/> 
											<fo:block> 
												<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/> 
											</fo:block> 
										</fo:block> 
									</fo:static-content> 
									<fo:static-content flow-name="xsl-region-after"> 
										<fo:block font-size="12pt" text-align="end"> 
											<fo:page-number/> 
										</fo:block> 
									</fo:static-content> 
									<fo:flow flow-name="xsl-region-body"> 
										<fo:block font-size="12pt"
															font-family="serif"
															line-height="18pt"
															font-weight="bold"
															text-align="start">
											<xsl:attribute name="id">
												<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
											</xsl:attribute>
											<xsl:value-of select="MetaData/General/Title"/>
										</fo:block>
										<xsl:apply-templates/>
									</fo:flow>
								</fo:page-sequence>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</fo:root>			
	</xsl:template>
	
	<xsl:template match="MetaData"/>
	
	<xsl:template match="Content/LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=2">
				<fo:block>
					<xsl:value-of select="MetaData/General/Title"/>
				</fo:block>
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif'">
						<fo:external-graphic>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
						</fo:external-graphic>
						<fo:block font-family="sans-serif"
											font-size="12pt"
											font-weight="bold"
											line-height="14pt"
											text-align="start">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung: </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure: </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Title"/>	
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="10pt"
											line-height="12pt"
											text-align="start"
											space-after="10pt">
							<xsl:apply-templates select="MetaData/General/Description"/>	
						</fo:block>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-jpeg'">
						<fo:external-graphic>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
						</fo:external-graphic>
						<fo:block font-family="sans-serif"
											font-size="12pt"
											font-weight="bold"
											line-height="14pt"
											text-align="start">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung: </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure: </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Title"/>	
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="10pt"
											line-height="12pt"
											text-align="start"
											space-after="10pt">
							<xsl:apply-templates select="MetaData/General/Description"/>	
						</fo:block>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-svg-xml'">
						<fo:external-graphic>
							<xsl:attribute name="src">
								<xsl:value-of select="concat(substring-before(MetaData/Technical/Location,'.'),'.',translate(substring-after(MetaData/Technical/Location,'.'),'svg','jpg'))"/>
							</xsl:attribute>
						</fo:external-graphic>
						<fo:block font-family="sans-serif"
											font-size="12pt"
											font-weight="bold"
											line-height="14pt"
											text-align="start">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung: </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure: </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Title"/>	
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="10pt"
											line-height="12pt"
											text-align="start"
											space-after="10pt">
							<xsl:apply-templates select="MetaData/General/Description"/>	
						</fo:block>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Test">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:text>Test</xsl:text>
		</fo:block>
		<xsl:for-each select="TestItem">
			<fo:block space-after="5mm">
				<fo:block font-family="serif" font-weight="bold">
					<xsl:choose>
						<xsl:when test="../../MetaData/General/Language='de'">
							<xsl:text>Frage </xsl:text>	
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Question </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:number count="TestItem"/>
				</fo:block>
				<xsl:apply-templates select="Question"/>
				<xsl:for-each select="Answer">
					<fo:block font-family="serif" font-weight="bold">
						<xsl:choose>
							<xsl:when test="../../../MetaData/General/Language='de'">
								<xsl:text>Antwort </xsl:text>	
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Answer </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>				
					<xsl:apply-templates/>
				</xsl:for-each>
			</fo:block>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Paragraph">
		<xsl:choose>
			<xsl:when test="@Characteristic='Headline'">
				<fo:block font-size="12pt"
									font-family="serif"
									font-weight="bold"
									line-height="18pt"
									text-align="justify"
									text-align-last="start"
									space-before="2mm"
									space-after="0mm"
									hyphenate="true"
									hyphenation-character="-"
									keep-with-next="always">
					<xsl:attribute name="language"> 
						<xsl:choose>
							<xsl:when test="@Language">
								<xsl:value-of select="@Language"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="//MetaData/General/Language"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:apply-templates/>
				</fo:block>
			</xsl:when>
			<xsl:when test="@Characteristic='Mnemonic'">
				<fo:block background-color="#cccccc"
									border-style="solid"
									margin-left="20px"
									margin-right="20px"
									margin-top="20px"
									margin-bottom="20px"
									padding="10px"
									font-size="12pt"
									font-family="serif"
									font-weight="bold"
									line-height="18pt"
									text-align="justify"
									text-align-last="start"
									space-before="0mm"
									space-after.optimum="2mm"
									space-after.minimum="0mm"
									hyphenate="true"
									hyphenation-character="-">
					<xsl:attribute name="language"> 
						<xsl:choose>
							<xsl:when test="@Language">
								<xsl:value-of select="@Language"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="//MetaData/General/Language"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:apply-templates/>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block font-size="12pt" 
									font-family="serif" 
									line-height="18pt" 
									text-align="justify"
									text-align-last="start"
									space-before="0mm"
									space-after.optimum="2mm"
									space-after.minimum="0mm"
									hyphenate="true"
									hyphenation-character="-"
									keep-with-next="always">
					<xsl:attribute name="language"> 
						<xsl:choose>
							<xsl:when test="@Language">
								<xsl:value-of select="@Language"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="//MetaData/General/Language"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:apply-templates/>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="List">
		<fo:block font-size="12pt" font-family="serif" line-height="18pt">
			<xsl:choose>
				<xsl:when test="@type='ordered'">
					<xsl:for-each select="Title">
						<fo:block>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:for-each>	
					<fo:list-block>
						<xsl:for-each select="Item">
							<fo:list-item>
								<fo:list-item-label end-indent="label-end()">
									<fo:block><xsl:number count="Item"/><xsl:text>.</xsl:text></fo:block>
								</fo:list-item-label>
								<fo:list-item-body start-indent="body-start()">
									<fo:block font-size="12pt" font-family="serif" line-height="18pt">
										<xsl:apply-templates/>
									</fo:block>
								</fo:list-item-body>
							</fo:list-item>
						</xsl:for-each>
 					</fo:list-block>
 				</xsl:when>	
 				<xsl:otherwise>
					<xsl:for-each select="Title">
						<fo:block>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:for-each>			
 					<fo:list-block>
 						<xsl:for-each select="Item">
 							<fo:list-item>
								<fo:list-item-label end-indent="label-end()">
									<fo:block>&#8226;</fo:block>
								</fo:list-item-label>
								<fo:list-item-body start-indent="body-start()">
									<fo:block>
										<xsl:apply-templates/>
									</fo:block>
								</fo:list-item-body>
							</fo:list-item>
						</xsl:for-each>
 					</fo:list-block>
 				</xsl:otherwise>
 			</xsl:choose>
 		</fo:block>
	</xsl:template>
	
	<xsl:template match="Link">
		<xsl:value-of select="."/>
		<fo:footnote>
			<fo:inline font-size="8pt" vertical-align="super">
				<xsl:number count="Link" level="any"/>
			</fo:inline>
			<fo:footnote-body>
				<fo:list-block>
					<fo:list-item>
						<fo:list-item-label end-indent="label-end()">
							<fo:block font-size="8pt" vertical-align="super">
								<xsl:number count="Link" level="any"/>
							</fo:block>
						</fo:list-item-label>	
						<fo:list-item-body start-indent="body-start()">
							<fo:block font-size="10pt">
								<xsl:value-of select="@Href"/>
							</fo:block>
						</fo:list-item-body>
					</fo:list-item>					
				</fo:list-block>
			</fo:footnote-body>
		</fo:footnote>
	</xsl:template>
	
	<xsl:template match="Emph">
		<fo:inline font-weight="bold">
			<xsl:value-of select="."/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="Strong">
		<fo:inline font-weight="bold" font-style="italic">
			<xsl:value-of select="."/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="Example">
		<fo:block font-weight="bold">
			<xsl:attribute name="id">
				<xsl:value-of select="@Id"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="translate(@Id,'_',' ')"/>
			<xsl:text> </xsl:text>
		</fo:block>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Example/*">
		<fo:block>
			<xsl:choose>
				<xsl:when test="../@Status='Ill-formed'">
					<xsl:text>* </xsl:text>
				</xsl:when>
				<xsl:when test="../@Status='Questionable'">
					<xsl:text>? </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="Code">
<!-- justify fuer Code muss noch ausgestellt werden -->
		<xsl:choose>
			<xsl:when test="@Display='Inline'">
				<fo:inline font-family="monospace"
									 text-align="start">
					<xsl:apply-templates/>
				</fo:inline>
			</xsl:when>
			<xsl:when test="@Display='Block'">
				<fo:block font-family="monospace"
									text-align="start">
					<xsl:choose>
						<xsl:when test="CodeElem">
							<xsl:for-each select="CodeElem">
								<fo:block>
									<xsl:value-of select="."/>
								</fo:block>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="Quotation">
		<xsl:choose>
			<xsl:when test="@Type='Block'">
				<fo:block>
					<fo:inline>
						<xsl:text>"</xsl:text><xsl:value-of select="."/><xsl:text>"</xsl:text>
						<xsl:if test="@Reference_to">
							<xsl:text> (in: </xsl:text>
							<xsl:for-each select="id(@Reference_to)/Author">
 								<xsl:apply-templates/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
 							<xsl:text>, </xsl:text>
 							<xsl:apply-templates select="id(@Reference_to)/Year"/>
 							<xsl:if test="Page">
 								<xsl:text>, S. </xsl:text>
 								<xsl:apply-templates select="@Page"/>
 							</xsl:if>
 							<xsl:text>)</xsl:text>
						</xsl:if>
					</fo:inline>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:inline>
					<xsl:text>"</xsl:text><xsl:value-of select="."/><xsl:text>"</xsl:text>
					<xsl:if test="@Reference_to">
						<xsl:text> (in: </xsl:text>
						<xsl:for-each select="id(@Reference_to)/Author">
 							<xsl:apply-templates/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
 						<xsl:text>, </xsl:text>
 						<xsl:apply-templates select="id(@Reference_to)/Year"/>
 						<xsl:if test="Page">
 							<xsl:text>, S. </xsl:text>
 							<xsl:apply-templates select="@Page"/>
 						</xsl:if>
 						<xsl:text>)</xsl:text>
					</xsl:if>
				</fo:inline>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
<!-- Table: Problem: die Konvertierung nach XSL-FO funktioniert wunderbar, allerdings kann FOP -->
<!-- die erzeugten Tabellen noch nicht anzeigen, da er eine vorgegebene Anzahl an Table-Column benoetigt -->
<!-- auch table-and-caption wird noch nicht unterstuetzt -->
	<xsl:template match="Table">
		<xsl:choose>
			<xsl:when test="HeaderCaption">
				<fo:table-and-caption caption-side="before">
					<fo:table-caption>
						<fo:block>
							<xsl:value-of select="HeaderCaption"/>
						</fo:block>
					</fo:table-caption>
					<fo:table>
						<fo:table-body>
							<xsl:for-each select="TableRow">
								<fo:table-row>
									<xsl:for-each select="TableData">
										<fo:table-cell>
											<fo:block>
												<xsl:value-of select="."/>
											</fo:block>
										</fo:table-cell>	
									</xsl:for-each>
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
					</fo:table>
				</fo:table-and-caption>
			</xsl:when>
			<xsl:when test="FooterCaption">
				<fo:table-and-caption caption-side="after">
					<fo:table-caption>
						<fo:block>
							<xsl:value-of select="FooterCaption"/>
						</fo:block>
					</fo:table-caption>
					<fo:table>
						<fo:table-body>
							<xsl:for-each select="TableRow">
								<fo:table-row>
									<xsl:for-each select="TableData">
										<fo:table-cell>
											<fo:block>
												<xsl:value-of select="."/>
											</fo:block>
										</fo:table-cell>	
									</xsl:for-each>
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
					</fo:table>
				</fo:table-and-caption>
			</xsl:when>
			<xsl:otherwise>
				<fo:table>
					<fo:table-body>
							<xsl:for-each select="TableRow">
								<fo:table-row>
									<xsl:for-each select="TableData">
										<fo:table-cell>
											<fo:block>
												<xsl:value-of select="."/>
											</fo:block>
										</fo:table-cell>	
									</xsl:for-each>
								</fo:table-row>
							</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
<!-- analog zur Bearbeitung von Bib am Anfang: noch zu ueberarbeiten -->	
	<xsl:template match="Bibliography">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<xsl:text>Literaturangaben</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Bibliography</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
		<xsl:for-each select="Bibitem">
			<xsl:sort select="subscript[1]/Author/Family"/>
			<fo:block font-family="serif"
								font-size="12pt"
								line-height="18pt"
								space-after="12pt">
				<xsl:choose>
					<xsl:when test="Author">
						<xsl:for-each select="Author">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>/</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="Editor">
						<xsl:for-each select="Editor">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:text> (Hrsg.), </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>/</xsl:text>
								</xsl:otherwise>
							</xsl:choose>			
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="Organization">
						<xsl:apply-templates select="Organization"/>
						<xsl:text>, </xsl:text>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="@Type='Internet'">
						<fo:block>
							<xsl:text> "</xsl:text>
							<xsl:value-of select="Title"/>
							<xsl:text>".</xsl:text>
						</fo:block>
						<xsl:if test="Edition">
							<fo:block>
								<xsl:value-of select="Edition"/>
							</fo:block>
						</xsl:if>
						<xsl:if test="Publisher">
							<xsl:apply-templates select="Publisher"/>
							<xsl:text>, </xsl:text>	
						</xsl:if>
						<xsl:for-each select="URL">
							<xsl:value-of select="."/>
							<xsl:if test="position()!=last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:if test="Year">
							<xsl:text>, </xsl:text>
							<xsl:value-of select="Year"/>
						</xsl:if>
						<xsl:text>.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:text> "</xsl:text>
							<xsl:value-of select="Title"/>
							<xsl:if test="Booktitle">
								<xsl:text>in: </xsl:text>
								<xsl:value-of select="Booktitle"/>
							</xsl:if>
							<xsl:text>".</xsl:text>
						</fo:block>
						<xsl:if test="Edition">
							<fo:block>
								<xsl:value-of select="Edition"/>
							</fo:block>
						</xsl:if>
						<xsl:if test="Publisher">
							<xsl:apply-templates select="Publisher"/>
							<xsl:text>, </xsl:text>	
						</xsl:if>
						<xsl:value-of select="Address"/>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="Year"/>
						<xsl:text>.</xsl:text>
					</xsl:otherwise>
				</xsl:choose>		
			</fo:block>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Glossary">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<xsl:text>Glossar</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Glossary</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
		<fo:table>
			<fo:table-column column-width="35mm"/>
			<fo:table-column column-width="125mm"/>		
			<fo:table-body font-size="12pt" font-family="serif">
				<xsl:for-each select="GlossaryItem">
					<xsl:sort select="GlossaryTerm/@Definition"/>
					<fo:table-row line-height="16pt">
						<fo:table-cell>
							<fo:block text-align="start">
								<xsl:value-of select="GlossaryTerm"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="start">
								<xsl:apply-templates select="Definition"/>
								<xsl:apply-templates select="Definitionlist"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template match="GlossaryTerm">
		<xsl:apply-templates/>
		<fo:inline font-size="8pt" color="red" vertical-align="super">G</fo:inline>
	</xsl:template>
	
	<xsl:template match="DefinitionList">
		<fo:block>
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="Reference">
		<fo:inline>
			<xsl:choose>
				<xsl:when test="@Type='LearningObject'">
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>siehe </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>cf </xsl:text>
						</xsl:when>
					</xsl:choose>
					&quot;<xsl:value-of select="id(@Reference_to)/../Title"/>&quot;
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>S. </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>p. </xsl:text>
						</xsl:when>
					</xsl:choose>
					<fo:page-number-citation>
						<xsl:attribute name="ref-id">
							<xsl:value-of select="@Reference_to"/>
						</xsl:attribute>
					</fo:page-number-citation>
				</xsl:when>
				<xsl:when test="@Type='RefTarget'">
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>siehe </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>cf </xsl:text>
						</xsl:when>
					</xsl:choose>
					&quot;<xsl:value-of select="id(@Reference_to)"/>&quot;
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>S. </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>p. </xsl:text>
						</xsl:when>
					</xsl:choose>
					<fo:page-number-citation>
						<xsl:attribute name="ref-id">
							<xsl:value-of select="@Reference_to"/>
						</xsl:attribute>
					</fo:page-number-citation>
				</xsl:when>
				<xsl:when test="@Type='BibliographyEntry'">
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>vgl. </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>cf </xsl:text>
						</xsl:when>
					</xsl:choose>
					<xsl:choose>
	 					<xsl:when test="id(@Reference_to)/Author">
	 						<xsl:for-each select="id(@Reference_to)/Author">
	 							<xsl:apply-templates select="Family"/>
	 							<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Editor">
							<xsl:for-each select="id(@Reference_to)/Editor">
								<xsl:apply-templates select="Family"/>
	 							<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
							<xsl:text> (Hrsg.)</xsl:text>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Organization">
							<xsl:for-each select="id(@Reference_to)/Organization">
								<xsl:apply-templates select="."/>
	 							<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Title"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="id(@Reference_to)/Year">
						<xsl:text>, </xsl:text>
	 					<xsl:apply-templates select="id(@Reference_to)/Year"/>
	 				</xsl:if>
	 				<xsl:if test="@Page">
	 					<xsl:text>, S. </xsl:text>
	 					<xsl:apply-templates select="@Page"/>
	 				</xsl:if>
				</xsl:when>
			</xsl:choose>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="RefTarget">
		<fo:inline>
			<xsl:attribute name="id">
				<xsl:value-of select="@Id"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<!-- to do: 
	
	Bibliographie, Referenzen, Nummerierung im TOC
	
	-->
	
</xsl:stylesheet>